==> haskell-binary-parser-0.5.7.7-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-parser
version:              0.5.7.7
visibility:           public
id:                   binary-parser-0.5.7.7-EWT2RERiqAe5vNkFQzAD2B
key:                  binary-parser-0.5.7.7-EWT2RERiqAe5vNkFQzAD2B
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    An efficient but limited parser API specialised to bytestrings

category:             Parser, Binary
abi:                  c98d0ce9f76919e394ef356478b36013
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-parser
hs-libraries:         HSbinary-parser-0.5.7.7-EWT2RERiqAe5vNkFQzAD2B
depends:
    base-4.17.2.1 bytestring-0.11.5.3 mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-parser-0.5.7.7-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-parser
version:              0.5.7.7
visibility:           public
id:                   binary-parser-0.5.7.7-4d4OFubNcwl2lnx2437rwG
key:                  binary-parser-0.5.7.7-4d4OFubNcwl2lnx2437rwG
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    An efficient but limited parser API specialised to bytestrings

category:             Parser, Binary
abi:                  d982d22580f8068b154d4dbf1e446239
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/binary-parser-0.5.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-parser
hs-libraries:         HSbinary-parser-0.5.7.7-4d4OFubNcwl2lnx2437rwG
depends:
    base-4.17.2.1 bytestring-0.11.5.3 mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
